IntoResolver

Trait IntoResolver 

pub trait IntoResolver<K = Spur>: Reader<K>
where K: Key,
{ type Resolver: Resolver<K>; // Required method fn into_resolver(self) -> Self::Resolver where Self: 'static; }
A generic interface over Readers that can be turned into a Resolver.

Required Associated Types

type Resolver: Resolver<K>

The type of Resolver the reader will be converted into

Required Methods

fn into_resolver(self) -> Self::Resolver
where Self: 'static,

Consumes the current Reader and makes it into a Resolver, allowing contention-free access from multiple threads with the lowest possible memory consumption

Implementations on Foreign Types

Source

impl<K, I> IntoResolver<K> for Box<I>
where K: Key, I: IntoResolver<K> + ?Sized + 'static,

Source

type Resolver = <I as IntoResolver<K>>::Resolver

Source

fn into_resolver(self) -> Self::Resolver
where Self: 'static,

Implementors

Source

impl<K, S> IntoResolver<K> for Rodeo<K, S>
where K: Key, S: BuildHasher,

Source

impl<K, S> IntoResolver<K> for RodeoReader<K, S>
where K: Key, S: BuildHasher,

Source

impl<K, S> IntoResolver<K> for ThreadedRodeo<K, S>
where K: Key + Hash, S: BuildHasher + Clone,

Available on crate feature multi-threaded only.